@@ -20,24 +20,30 @@ struct _InputSynthClass
 {
   GObjectClass parent_class;
   void (*move_cursor) (InputSynth *self, int x, int y);
-
   void (*click) (InputSynth *self, int x, int y, int button, gboolean press);
-
   void (*character) (InputSynth *self, char c);
-
   GString * (*get_backend_name) (InputSynth *self);
 };
 
-typedef enum
-{
-  InputsynthBackend_XI2,
-  InputsynthBackend_XDO,
-  InputsynthBackend_WAYLAND_CLUTTER
+/**
+ * InputsynthBackend:
+ * @INPUTSYNTH_BACKEND_XI2: Use XTestFake events to synthesize input.
+ * Optionally create a second mouse cursor with xinput2.
+ * @INPUTSYNTH_BACKEND_XDO: Use libxdo from xdotools.
+ * @INPUTSYNTH_BACKEND_WAYLAND_CLUTTER: Use Clutter's remote input API to
+ * synthesize input on gnome wayland.
+ *
+ * Type of backend to use.
+ *
+ */
+typedef enum {
+  INPUTSYNTH_BACKEND_XI2,
+  INPUTSYNTH_BACKEND_XDO,
+  INPUTSYNTH_BACKEND_WAYLAND_CLUTTER
 } InputsynthBackend;
 
 InputSynth *input_synth_new (InputsynthBackend backend);
 
-/* the x and y coordinates are relative to the entire desktop */
 void
 input_synth_move_cursor (InputSynth *self, int x, int y);
 
