@@ -10,7 +10,7 @@
 int
 main ()
 {
-  InputSynth *input = INPUT_SYNTH (input_synth_new (InputsynthBackend_XDO));
+  InputSynth *input = INPUT_SYNTH (input_synth_new (INPUTSYNTH_BACKEND_XDO));
   g_assert (input != NULL);
   GString *name = input_synth_get_backend_name (input);
   g_print ("Input Synth Backend: %s\n", name->str);
